@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::authors;
 
-our $DATE = '2018-01-15'; # DATE
-our $VERSION = '1.020'; # VERSION
+our $DATE = '2018-02-08'; # DATE
+our $VERSION = '1.021'; # VERSION
 
 use 5.010;
 use strict;
@@ -29,7 +29,7 @@ App::lcpan::Cmd::authors - List authors
 
 =head1 VERSION
 
-This document describes version 1.020 of App::lcpan::Cmd::authors (from Perl distribution App-lcpan), released on 2018-01-15.
+This document describes version 1.021 of App::lcpan::Cmd::authors (from Perl distribution App-lcpan), released on 2018-02-08.
 
 =head1 FUNCTIONS
 
@@ -52,7 +52,7 @@ Examples:
 
 =item * Find CPAN IDs which start with something:
 
- handle_cmd( query => ["MICHAEL%"]); # -> ["MICHAEL", "MICHAELW", undef, {}]
+ handle_cmd( query => ["MICHAEL%"]); # -> undef
 
 =back
 
